==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/AuthenticationSpecificationImpl.java <==
package com.jayway.restassured.internal;

import com.jayway.restassured.authentication.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class AuthenticationSpecificationImpl
  extends java.lang.Object  implements
    com.jayway.restassured.specification.AuthenticationSpecification,    groovy.lang.GroovyObject {
public AuthenticationSpecificationImpl
(com.jayway.restassured.specification.RequestSpecification requestSpecification) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.RequestSpecification basic(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification digest(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification certificate(java.lang.String certURL, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification oauth(java.lang.String consumerKey, java.lang.String consumerSecret, java.lang.String accessToken, java.lang.String secretToken) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification none() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.PreemptiveAuthSpec preemptive() { return (com.jayway.restassured.specification.PreemptiveAuthSpec)null;}
public  com.jayway.restassured.specification.RequestSpecification form(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification form(java.lang.String userName, java.lang.String password, com.jayway.restassured.authentication.FormAuthConfig config) { return (com.jayway.restassured.specification.RequestSpecification)null;}
}

==> rest-assured-2.6.0-sources.jar: com/jayway/restassured/internal/AuthenticationSpecificationImpl.java <==
package com.jayway.restassured.internal;

import com.jayway.restassured.authentication.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class AuthenticationSpecificationImpl
  extends java.lang.Object  implements
    com.jayway.restassured.specification.AuthenticationSpecification,    groovy.lang.GroovyObject {
public AuthenticationSpecificationImpl
(com.jayway.restassured.specification.RequestSpecification requestSpecification) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.RequestSpecification basic(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification digest(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification certificate(java.lang.String certURL, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification certificate(java.lang.String certURL, java.lang.String password, com.jayway.restassured.authentication.CertificateAuthSettings settings) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification certificate(java.lang.String certURL, java.lang.String password, java.lang.String keystoreType, int port) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification oauth(java.lang.String consumerKey, java.lang.String consumerSecret, java.lang.String accessToken, java.lang.String secretToken) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification oauth(java.lang.String consumerKey, java.lang.String consumerSecret, java.lang.String accessToken, java.lang.String secretToken, com.jayway.restassured.authentication.OAuthSignature signature) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification oauth2(java.lang.String accessToken) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification oauth2(java.lang.String accessToken, com.jayway.restassured.authentication.OAuthSignature signature) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification none() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.PreemptiveAuthSpec preemptive() { return (com.jayway.restassured.specification.PreemptiveAuthSpec)null;}
public  com.jayway.restassured.specification.RequestSpecification form(java.lang.String userName, java.lang.String password) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification form(java.lang.String userName, java.lang.String password, com.jayway.restassured.authentication.FormAuthConfig config) { return (com.jayway.restassured.specification.RequestSpecification)null;}
}
